@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2017 Maxime DOYEN
+ *  Copyright (C) 1995-2018 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -46,6 +46,14 @@ guint32		da_tag_get_max_key(void);
 Tag		*da_tag_get_by_name(gchar *name);
 Tag		*da_tag_get(guint32 key);
 
+
+guint tags_count(guint32 *tags);
+guint32 *tags_clone(guint32 *tags);
+guint32 *tags_parse(const gchar *tagstring);
+gchar *tags_tostring(guint32 *tags);
+
+
+
 GList *tag_glist_sorted(gint column);
 
 #endif
