@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2017 Maxime DOYEN
+ *  Copyright (C) 1995-2018 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -84,7 +84,7 @@ static GOptionEntry option_entries[] =
 gint homebank_alienfile_recognize(gchar *filename)
 {
 GIOChannel *io;
-gint i, retval = FILETYPE_UNKNOW;
+gint i, retval = FILETYPE_UNKNOWN;
 gchar *tmpstr;
 gint io_stat;
 GError *err = NULL;
@@ -109,7 +109,7 @@ static gint csvtype[7] = {
 
 		for(i=0;i<25;i++)
 		{
-			if( retval != FILETYPE_UNKNOW )
+			if( retval != FILETYPE_UNKNOWN )
 				break;
 
 			io_stat = g_io_channel_read_line(io, &tmpstr, NULL, NULL, &err);
@@ -246,11 +246,13 @@ gboolean retval = FALSE;
 
 	if( g_file_test(filepath, G_FILE_TEST_EXISTS) )
 	{
+		DB( g_print(" - deleting: '%s'\n", filepath) );
 		g_remove(filepath);
 		retval = TRUE;
 	}
+	else
+		DB( g_print(" - cannot delete: '%s'\n", filepath) );
 
-	DB( g_print(" - deleted: '%s' :: %d\n", filepath, retval) );
 	return retval;
 }
 
@@ -258,6 +260,8 @@ gboolean retval = FALSE;
 void homebank_backup_current_file(void)
 {
 gchar *bakfilename;
+GPtrArray *array;
+gint i;
 
 	DB( g_print("\n[homebank] backup_current_file\n") );
 
@@ -269,6 +273,47 @@ gchar *bakfilename;
 	//retval = g_rename(pathname, newname);
 	homebank_file_copy (GLOBALS->xhb_filepath, bakfilename);
 	g_free(bakfilename);
+
+	//do safe backup according to user preferences
+	DB( g_print(" user pref backup\n") );	
+	if( PREFS->bak_is_automatic == TRUE )
+	{
+		bakfilename = hb_filename_new_for_backup(GLOBALS->xhb_filepath);
+		if( g_file_test(bakfilename, G_FILE_TEST_EXISTS) == FALSE )
+		{
+			homebank_file_copy (GLOBALS->xhb_filepath, bakfilename);
+		}
+		g_free(bakfilename);
+
+		//delete any offscale backup
+		DB( g_print(" clean old backup\n") );
+		array = hb_filename_backup_list(GLOBALS->xhb_filepath);
+
+		DB( g_print(" found %d match\n", array->len) );
+
+		gchar *dirname = g_path_get_dirname(GLOBALS->xhb_filepath);
+		
+		for(i=0;i<(gint)array->len;i++)
+		{
+		gchar *offscalefilename = g_ptr_array_index(array, i);
+	
+			DB( g_print(" %d : '%s'\n", i, offscalefilename) );
+			if( i >= PREFS->bak_max_num_copies )
+			{
+			gchar *bakdelfilepath = g_build_filename(dirname, offscalefilename, NULL);
+
+				DB( g_print(" - should delete '%s'\n", bakdelfilepath) );
+			
+				homebank_file_delete_existing(bakdelfilepath);
+
+				g_free(bakdelfilepath);
+			}
+		}
+		g_ptr_array_free(array, TRUE);
+
+		g_free(dirname);
+	}
+
 }
 
 
@@ -398,24 +443,28 @@ gsize length;
 
 	if( GLOBALS->xhb_filepath != NULL )
 	{
-		keyfile = g_key_file_new();
-		if(keyfile )
+		//don't save bakup files
+		if( hbfile_file_isbackup(GLOBALS->xhb_filepath) == FALSE )
 		{
-			DB( g_print(" - saving '%s'\n", GLOBALS->xhb_filepath) );
+			keyfile = g_key_file_new();
+			if(keyfile )
+			{
+				DB( g_print(" - saving '%s'\n", GLOBALS->xhb_filepath) );
 
-			group = "HomeBank";
-			g_key_file_set_string  (keyfile, group, "LastOpenedFile", GLOBALS->xhb_filepath);
+				group = "HomeBank";
+				g_key_file_set_string  (keyfile, group, "LastOpenedFile", GLOBALS->xhb_filepath);
 
-			gchar *contents = g_key_file_to_data( keyfile, &length, NULL);
+				gchar *contents = g_key_file_to_data( keyfile, &length, NULL);
 
-			//DB( g_print(" keyfile:\n%s\nlen=%d\n", contents, length) );
+				//DB( g_print(" keyfile:\n%s\nlen=%d\n", contents, length) );
 
-			filename = g_build_filename(homebank_app_get_config_dir(), "lastopenedfiles", NULL );
-			g_file_set_contents(filename, contents, length, NULL);
-			g_free(filename);
+				filename = g_build_filename(homebank_app_get_config_dir(), "lastopenedfiles", NULL );
+				g_file_set_contents(filename, contents, length, NULL);
+				g_free(filename);
 
-			g_free(contents);
-			g_key_file_free (keyfile);
+				g_free(contents);
+				g_key_file_free (keyfile);
+			}
 		}
 	}
 
