@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2017 Maxime DOYEN
+ *  Copyright (C) 1995-2018 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -181,22 +181,25 @@ Payee *pay;
 }
 
 /*
-** wording cell function
+** memo cell function
 */
-static void wording_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+static void memo_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
 Archive *arc;
-gchar *txt;
+gchar *memo;
 gint weight;
 
 	gtk_tree_model_get(model, iter,
 		LST_DSPUPC_DATAS, &arc,
-		LST_DSPUPC_WORDING, &txt,
+		LST_DSPUPC_MEMO, &memo,
 		-1);
 
 	weight = arc == NULL ? PANGO_WEIGHT_BOLD : PANGO_WEIGHT_NORMAL;
 
-	g_object_set(renderer, "weight", weight, "text", txt, NULL);
+	g_object_set(renderer, "weight", weight, "text", memo, NULL);
+
+	//leak
+	g_free(memo);
 
 }
 
@@ -326,7 +329,7 @@ GtkTreeViewColumn  *column;
 	  	NUM_LST_DSPUPC,
 		G_TYPE_POINTER,
 		G_TYPE_BOOLEAN,	/* payee */
-		G_TYPE_STRING,	/* wording */
+		G_TYPE_STRING,	/* memo */
 		G_TYPE_DOUBLE,	/* expense */
 		G_TYPE_DOUBLE,	/* income */
 		G_TYPE_POINTER,	/* account */
@@ -406,7 +409,7 @@ GtkTreeViewColumn  *column;
 
 	gtk_tree_view_column_set_fixed_width(column, PREFS->pnl_upc_col_pay_width);
 
-	/* column: Wording */
+	/* column: Memo */
 	renderer = gtk_cell_renderer_text_new ();
 	g_object_set(renderer, 
 		"ellipsize", PANGO_ELLIPSIZE_END,
@@ -416,7 +419,7 @@ GtkTreeViewColumn  *column;
 	column = gtk_tree_view_column_new();
 	gtk_tree_view_column_set_title(column, _("Memo"));
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
-	gtk_tree_view_column_set_cell_data_func(column, renderer, wording_cell_data_function, NULL, NULL);
+	gtk_tree_view_column_set_cell_data_func(column, renderer, memo_cell_data_function, NULL, NULL);
 	gtk_tree_view_column_set_resizable(column, TRUE);
 	//gtk_tree_view_column_add_attribute(column, renderer, "text", 2);
 	//gtk_tree_view_column_set_sort_column_id (column, LST_DSPACC_NAME);
