@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2017 Maxime DOYEN
+ *  Copyright (C) 1995-2018 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -100,11 +100,12 @@ struct ui_acc_manage_data
 	GtkWidget	*CM_noreport;
 	GtkWidget	*CM_closed;
 	GtkWidget	*ST_initial;
-	GtkWidget	*ST_warning;
+	//GtkWidget	*ST_warning;
 	GtkWidget	*ST_overdraft;
 	GtkWidget	*ST_cheque1;
 	GtkWidget	*ST_cheque2;
 	GtkWidget	*TB_notes;
+	GtkWidget	*CY_template;
 	
 };
 
