@@ -84,7 +84,6 @@ gdouble value;
 	}
 
 	item->kcur = GLOBALS->kcur;
-	
 	item->type = gtk_combo_box_get_active(GTK_COMBO_BOX(data->CY_type));
 
 	item->number = g_strdup(gtk_entry_get_text(GTK_ENTRY(data->ST_number)));
@@ -373,7 +372,7 @@ gint row;
 	gtk_box_pack_start (GTK_BOX (box), table, TRUE, TRUE, 0);
 
 	row = 0;
-	label = make_label_group(_("Informations"));
+	label = make_label_group(_("Information"));
 	gtk_grid_attach (GTK_GRID (table), label, 0, row, 3, 1);
 
 	row++;
