@@ -417,12 +417,14 @@ gint crow, row;
 
 
 
-static void ui_file_chooser_add_filter(GtkFileChooser *chooser, gchar *name, gchar *pattern)
+static GtkFileFilter *ui_file_chooser_add_filter(GtkFileChooser *chooser, gchar *name, gchar *pattern)
 {
 	GtkFileFilter *filter = gtk_file_filter_new ();
 	gtk_file_filter_set_name (filter, name);
 	gtk_file_filter_add_pattern (filter, pattern);
 	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER(chooser), filter);
+
+	return filter;
 }
 
 
@@ -529,7 +531,7 @@ gchar *path;
 /*
 ** open a file chooser dialog and store filename to GLOBALS if OK
 */
-gboolean ui_file_chooser_xhb(GtkFileChooserAction action, gchar **storage_ptr)
+gboolean ui_file_chooser_xhb(GtkFileChooserAction action, gchar **storage_ptr, gboolean bakmode)
 {
 GtkWidget *chooser;
 gchar *title;
@@ -540,7 +542,7 @@ gboolean retval;
 
 	if( action == GTK_FILE_CHOOSER_ACTION_OPEN )
 	{
-		title = _("Open HomeBank file");
+		title = (bakmode==FALSE) ? _("Open HomeBank file") : _("Open HomeBank backup file");
 		button = _("_Open");
 	}
 	else
@@ -556,10 +558,27 @@ gboolean retval;
 					button, GTK_RESPONSE_ACCEPT,
 					NULL);
 
-	ui_file_chooser_add_filter(GTK_FILE_CHOOSER(chooser), _("HomeBank files"), "*.[Xx][Hh][Bb]");
-	//ui_file_chooser_add_filter(GTK_FILE_CHOOSER(chooser), _("Backup files"), "*.[Bb][Aa][Kk]");
-	ui_file_chooser_add_filter(GTK_FILE_CHOOSER(chooser), _("All files"), "*");
+	if( bakmode == FALSE )
+	{
+		ui_file_chooser_add_filter(GTK_FILE_CHOOSER(chooser), _("HomeBank files"), "*.[Xx][Hh][Bb]");
+		ui_file_chooser_add_filter(GTK_FILE_CHOOSER(chooser), _("All files"), "*");
+	}
+	else
+	{
+		if( (action == GTK_FILE_CHOOSER_ACTION_OPEN) )
+		{
+		gchar *pattern;
+		GtkFileFilter *flt;
 
+			pattern = hb_filename_backup_get_filtername(GLOBALS->xhb_filepath);
+			flt = ui_file_chooser_add_filter(GTK_FILE_CHOOSER(chooser), _("File backup"), pattern);
+			gtk_file_chooser_set_filter(GTK_FILE_CHOOSER(chooser), flt);
+			g_free(pattern);
+
+			ui_file_chooser_add_filter(GTK_FILE_CHOOSER(chooser), _("All backups"), "*.[Bb][Aa][Kk]");
+		}
+	}
+	
 	if( action == GTK_FILE_CHOOSER_ACTION_OPEN )
 	{
 	    gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER(chooser), PREFS->path_hbfile);
@@ -710,11 +729,11 @@ GtkWidget *label, *widget, *BT_folder, *ST_name;
 gchar *tmpstr;
 gint crow, row;
 
-	dialog = gtk_dialog_new_with_buttons (_("Export PDF"),
+	dialog = gtk_dialog_new_with_buttons (_("Export as PDF"),
 		GTK_WINDOW (parent),
 		0,
 		_("_Cancel"), GTK_RESPONSE_CANCEL,
-		_("_Export"), GTK_RESPONSE_ACCEPT,
+		_("Export as _PDF"), GTK_RESPONSE_ACCEPT,
 		NULL);
 
 	gtk_window_set_default_size (GTK_WINDOW(dialog), HB_MINWIDTH_LIST, -1);
@@ -770,14 +789,19 @@ gint crow, row;
 
 	if(result == GTK_RESPONSE_ACCEPT)
 	{
-	gchar *nufolder = gtk_file_chooser_get_current_folder(GTK_FILE_CHOOSER(BT_folder));
-	gchar *nufilename = hb_filename_new_with_extension((gchar *)gtk_entry_get_text (GTK_ENTRY(ST_name)), "pdf");
-		
+	gchar *hostname;
+	//#300380 fixed export path problem (was always the export of preference)
+	//not to be used -- gchar *nufolder = gtk_file_chooser_get_current_folder(GTK_FILE_CHOOSER(BT_folder));
+	gchar *urifolder  = gtk_file_chooser_get_uri(GTK_FILE_CHOOSER(BT_folder));
+	gchar *nufolder   = g_filename_from_uri(urifolder, &hostname, NULL);
+	gchar *nufilename = hb_filename_new_with_extension((gchar *)gtk_entry_get_text (GTK_ENTRY(ST_name)), "pdf");	
+
 		g_free(*storage_ptr);
 		*storage_ptr = g_build_filename(nufolder, nufilename, NULL);
 
 		g_free(nufilename);
 		g_free(nufolder);
+		g_free(urifolder);
 	}
 
 	// cleanup and destroy
@@ -835,7 +859,7 @@ static void ui_dialog_transaction_xfer_select_child_selection_cb(GtkTreeSelectio
 }
 
 
-Transaction *ui_dialog_transaction_xfer_select_child(Transaction *stxn, GList *matchlist)
+Transaction *ui_dialog_transaction_xfer_select_child(GtkWindow *parent, Transaction *stxn, GList *matchlist)
 {
 struct xfer_data data;
 GtkWidget *window, *content, *mainvbox, *vbox, *sw, *label, *LB_several;
@@ -845,7 +869,7 @@ Transaction *retval = NULL;
 
 	window = gtk_dialog_new_with_buttons (
     			_("Select among possible transactions..."),
-    			GTK_WINDOW (GLOBALS->mainwindow),
+    			parent,
 			    0,
 			    _("_Cancel"),
 			    GTK_RESPONSE_REJECT,
