@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2017 Maxime DOYEN
+ *  Copyright (C) 1995-2018 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -140,7 +140,7 @@ gint i;
 
 			//data->filter->cat[i] = gtk_tree_selection_iter_is_selected(selection, &iter);
 			//data->filter->cat[i] = toggled;
-			catitem->filter = toggled;
+			catitem->flt_select = toggled;
 
 			n_child = gtk_tree_model_iter_n_children (GTK_TREE_MODEL(model), &iter);
 			gtk_tree_model_iter_children (GTK_TREE_MODEL(model), &child, &iter);
@@ -156,7 +156,7 @@ gint i;
 
 				//data->filter->cat[i] = toggled;
 				//data->filter->cat[i] = gtk_tree_selection_iter_is_selected(selection, &child);
-				catitem->filter = toggled;
+				catitem->flt_select = toggled;
 
 				n_child--;
 				gtk_tree_model_iter_next(GTK_TREE_MODEL(model), &child);
@@ -200,7 +200,7 @@ static void ui_flt_panel_category_set(struct ui_flt_manage_data *data)
 				LST_DEFCAT_DATAS, &catitem,
 				-1);
 
-			if(catitem->filter == TRUE)
+			if(catitem->flt_select == TRUE)
 				gtk_tree_store_set (GTK_TREE_STORE (model), &iter, LST_DEFCAT_TOGGLE, TRUE, -1);
 
 			n_child = gtk_tree_model_iter_n_children (GTK_TREE_MODEL(model), &iter);
@@ -213,7 +213,7 @@ static void ui_flt_panel_category_set(struct ui_flt_manage_data *data)
 					LST_DEFCAT_DATAS, &catitem,
 					-1);
 
-				if(catitem->filter == TRUE)
+				if(catitem->flt_select == TRUE)
 					gtk_tree_store_set (GTK_TREE_STORE (model), &child, LST_DEFCAT_TOGGLE, TRUE, -1);
 
 				n_child--;
@@ -638,7 +638,7 @@ gboolean sensitive;
 	active = gtk_combo_box_get_active(GTK_COMBO_BOX(data->CY_option[FILTER_TEXT]));
 	sensitive = active == 0 ? FALSE : TRUE;
 	gtk_widget_set_sensitive(data->CM_exact, sensitive);
-	gtk_widget_set_sensitive(data->ST_wording, sensitive);
+	gtk_widget_set_sensitive(data->ST_memo, sensitive);
 	gtk_widget_set_sensitive(data->ST_info, sensitive);
 	gtk_widget_set_sensitive(data->ST_tag, sensitive);
 
@@ -737,19 +737,19 @@ gchar *txt;
 		data->filter->minamount = gtk_spin_button_get_value(GTK_SPIN_BUTTON(data->ST_minamount));
 		data->filter->maxamount = gtk_spin_button_get_value(GTK_SPIN_BUTTON(data->ST_maxamount));
 
-	//text:wording
+	//text:memo
 		data->filter->exact  = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_exact));
 		//free any previous string
-		if(	data->filter->wording )
+		if(	data->filter->memo )
 		{
-			g_free(data->filter->wording);
-			data->filter->wording = NULL;
+			g_free(data->filter->memo);
+			data->filter->memo = NULL;
 		}
-		txt = (gchar *)gtk_entry_get_text(GTK_ENTRY(data->ST_wording));
+		txt = (gchar *)gtk_entry_get_text(GTK_ENTRY(data->ST_memo));
 
 		if (txt && *txt)	// ignore if entry is empty
 		{
-			data->filter->wording = g_strdup(txt);
+			data->filter->memo = g_strdup(txt);
 		}
 
 	//text:info
@@ -799,7 +799,7 @@ gchar *txt;
 					-1);
 
 				//data->filter->acc[i] = gtk_tree_selection_iter_is_selected(selection, &iter);
-				accitem->filter = toggled;
+				accitem->flt_select = toggled;
 
 				/* Make iter point to the next row in the list store */
 				i++; valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(model), &iter);
@@ -822,7 +822,7 @@ gchar *txt;
 				-1);
 
 			//data->filter->pay[i] = gtk_tree_selection_iter_is_selected(selection, &iter);
-			payitem->filter = toggled;
+			payitem->flt_select = toggled;
 
 			/* Make iter point to the next row in the list store */
 			i++; valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(model), &iter);
@@ -902,7 +902,7 @@ static void ui_flt_manage_set(struct ui_flt_manage_data *data)
 	//text
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_exact), data->filter->exact);
 	gtk_entry_set_text(GTK_ENTRY(data->ST_info), (data->filter->info != NULL) ? data->filter->info : "");
-	gtk_entry_set_text(GTK_ENTRY(data->ST_wording), (data->filter->wording != NULL) ? data->filter->wording : "");
+	gtk_entry_set_text(GTK_ENTRY(data->ST_memo), (data->filter->memo != NULL) ? data->filter->memo : "");
 	gtk_entry_set_text(GTK_ENTRY(data->ST_tag), (data->filter->tag != NULL) ? data->filter->tag : "");
 
 	//account
@@ -921,7 +921,7 @@ static void ui_flt_manage_set(struct ui_flt_manage_data *data)
 					LST_DEFACC_DATAS, &accitem,
 					-1);
 
-				if(accitem->filter == TRUE)
+				if(accitem->flt_select == TRUE)
 					//gtk_tree_selection_select_iter(selection, &iter);
 					gtk_list_store_set (GTK_LIST_STORE (model), &iter,
 						LST_DEFACC_TOGGLE, TRUE, -1);
@@ -945,7 +945,7 @@ static void ui_flt_manage_set(struct ui_flt_manage_data *data)
 				LST_DEFPAY_DATAS, &payitem,
 				-1);
 
-			if(payitem->filter == TRUE)
+			if(payitem->flt_select == TRUE)
 				gtk_list_store_set (GTK_LIST_STORE (model), &iter, LST_DEFPAY_TOGGLE, TRUE, -1);
 
 			/* Make iter point to the next row in the list store */
@@ -999,7 +999,7 @@ static void ui_flt_manage_setup(struct ui_flt_manage_data *data)
 	{
 		//gtk_tree_selection_set_mode(GTK_TREE_SELECTION(gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_pay))), GTK_SELECTION_MULTIPLE);
 
-		ui_pay_listview_populate(data->LV_pay);
+		ui_pay_listview_populate(data->LV_pay, NULL);
 		//populate_view_pay(data->LV_pay, GLOBALS->pay_list, FALSE);
 	}
 
@@ -1212,9 +1212,9 @@ gint row;
 	row++;
 	label = make_label_widget(_("_Memo:"));
 	gtk_grid_attach (GTK_GRID (table), label, 0, row, 1, 1);
-	data->ST_wording = make_string(label);
-	gtk_widget_set_hexpand (data->ST_wording, TRUE);
-	gtk_grid_attach (GTK_GRID (table), data->ST_wording, 1, row, 2, 1);
+	data->ST_memo = make_string(label);
+	gtk_widget_set_hexpand (data->ST_memo, TRUE);
+	gtk_grid_attach (GTK_GRID (table), data->ST_memo, 1, row, 2, 1);
 
 	row++;
 	label = make_label_widget(_("_Info:"));
